@@ -1,25 +1,31 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2024, by Samuel Williams.
+# Copyright, 2018-2025, by Samuel Williams.
 
-require 'fiber'
-require 'async/clock'
+require "fiber"
+require "async/clock"
 
-require_relative 'error'
+require_relative "error"
 
 module Async
 	module Container
 		# Manages a group of running processes.
 		class Group
 			# Initialize an empty group.
-			def initialize
+			#
+			# @parameter health_check_interval [Numeric | Nil] The (biggest) interval at which health checks are performed.
+			def initialize(health_check_interval: 1.0)
+				@health_check_interval = health_check_interval
+				
+				# The running fibers, indexed by IO:
 				@running = {}
 				
 				# This queue allows us to wait for processes to complete, without spawning new processes as a result.
 				@queue = nil
 			end
 			
+			# @returns [String] A human-readable representation of the group.
 			def inspect
 				"#<#{self.class} running=#{@running.size}>"
 			end
@@ -27,6 +33,11 @@ module Async
 			# @attribute [Hash(IO, Fiber)] the running tasks, indexed by IO.
 			attr :running
 			
+			# @returns [Integer] The number of running processes.
+			def size
+				@running.size
+			end
+			
 			# Whether the group contains any running processes.
 			# @returns [Boolean]
 			def running?
@@ -57,15 +68,43 @@ module Async
 			def wait
 				self.resume
 				
-				while self.running?
-					self.wait_for_children
+				with_health_checks do |duration|
+					self.wait_for_children(duration)
+				end
+			end
+			
+			private def with_health_checks
+				if @health_check_interval
+					health_check_clock = Clock.start
+					
+					while self.running?
+						duration = [@health_check_interval - health_check_clock.total, 0].max
+						
+						yield duration
+						
+						if health_check_clock.total > @health_check_interval
+							self.health_check!
+							health_check_clock.reset!
+						end
+					end
+				else
+					while self.running?
+						yield nil
+					end
+				end
+			end
+			
+			# Perform a health check on all running processes.
+			def health_check!
+				@running.each_value do |fiber|
+					fiber.resume(:health_check!)
 				end
 			end
 			
 			# Interrupt all running processes.
 			# This resumes the controlling fiber with an instance of {Interrupt}.
 			def interrupt
-				Console.logger.debug(self, "Sending interrupt to #{@running.size} running processes...")
+				Console.info(self, "Sending interrupt to #{@running.size} running processes...")
 				@running.each_value do |fiber|
 					fiber.resume(Interrupt)
 				end
@@ -74,7 +113,7 @@ module Async
 			# Terminate all running processes.
 			# This resumes the controlling fiber with an instance of {Terminate}.
 			def terminate
-				Console.logger.debug(self, "Sending terminate to #{@running.size} running processes...")
+				Console.info(self, "Sending terminate to #{@running.size} running processes...")
 				@running.each_value do |fiber|
 					fiber.resume(Terminate)
 				end
@@ -83,6 +122,7 @@ module Async
 			# Stop all child processes using {#terminate}.
 			# @parameter timeout [Boolean | Numeric | Nil] If specified, invoke a graceful shutdown using {#interrupt} first.
 			def stop(timeout = 1)
+				Console.debug(self, "Stopping all processes...", timeout: timeout)
 				# Use a default timeout if not specified:
 				timeout = 1 if timeout == true
 				
@@ -105,7 +145,7 @@ module Async
 				end
 				
 				# Terminate all children:
-				self.terminate
+				self.terminate if any?
 				
 				# Wait for all children to exit:
 				self.wait
@@ -118,15 +158,19 @@ module Async
 				@running[io] = Fiber.current
 				
 				while @running.key?(io)
+					# Wait for some event on the channel:
 					result = Fiber.yield
 					
 					if result == Interrupt
 						channel.interrupt!
 					elsif result == Terminate
 						channel.terminate!
+					elsif result
+						yield result
 					elsif message = channel.receive
 						yield message
 					else
+						# Wait for the channel to exit:
 						return channel.wait
 					end
 				end
@@ -137,14 +181,25 @@ module Async
 			protected
 			
 			def wait_for_children(duration = nil)
-				Console.debug(self, "Waiting for children...", duration: duration)
+				# This log is a big noisy and doesn't really provide a lot of useful information.
+				# Console.debug(self, "Waiting for children...", duration: duration, running: @running)
+				
 				if !@running.empty?
 					# Maybe consider using a proper event loop here:
+					if ready = self.select(duration)
+						ready.each do |io|
+							@running[io].resume
+						end
+					end
+				end
+			end
+			
+			# Wait for a child process to exit OR a signal to be received.
+			def select(duration)
+				::Thread.handle_interrupt(SignalException => :immediate) do
 					readable, _, _ = ::IO.select(@running.keys, nil, nil, duration)
 					
-					readable&.each do |io|
-						@running[io].resume
-					end
+					return readable
 				end
 			end
 			
