@@ -1,14 +1,21 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2022, by Samuel Williams.
+# Copyright, 2018-2025, by Samuel Williams.
 
 require "async/container/controller"
+require "async/container/controllers"
 
 describe Async::Container::Controller do
 	let(:controller) {subject.new}
 	
-	with '#reload' do
+	with "#to_s" do
+		it "can generate string representation" do
+			expect(controller.to_s).to be == "Async::Container::Controller stopped"
+		end
+	end
+	
+	with "#reload" do
 		it "can reuse keyed child" do
 			input, output = IO.pipe
 			
@@ -18,18 +25,16 @@ describe Async::Container::Controller do
 				container.spawn(key: "test") do |instance|
 					instance.ready!
 					
-					sleep(0.2)
-					
 					@output.write(".")
 					@output.flush
 					
-					sleep(0.4)
+					sleep(0.2)
 				end
 				
 				container.spawn do |instance|
 					instance.ready!
 					
-					sleep(0.3)
+					sleep(0.1)
 					
 					@output.write(",")
 					@output.flush
@@ -37,16 +42,20 @@ describe Async::Container::Controller do
 			end
 			
 			controller.start
+			
+			expect(controller.state_string).to be == "running"
+			
 			expect(input.read(2)).to be == ".,"
 			
 			controller.reload
 			
 			expect(input.read(1)).to be == ","
+			
 			controller.wait
 		end
 	end
 	
-	with '#start' do
+	with "#start" do
 		it "can start up a container" do
 			expect(controller).to receive(:setup)
 			
@@ -64,7 +73,7 @@ describe Async::Container::Controller do
 		it "can spawn a reactor" do
 			def controller.setup(container)
 				container.async do |task|
-					task.sleep 1
+					task.sleep 0.001
 				end
 			end
 			
@@ -88,8 +97,8 @@ describe Async::Container::Controller do
 		end
 	end
 	
-	with 'graceful controller' do
-		let(:controller_path) {File.expand_path(".graceful.rb", __dir__)}
+	with "graceful controller" do
+		let(:controller_path) {Async::Container::Controllers.path_for("graceful")}
 		
 		let(:pipe) {IO.pipe}
 		let(:input) {pipe.first}
@@ -104,7 +113,7 @@ describe Async::Container::Controller do
 			super
 		end
 		
-		def after
+		def after(error = nil)
 			Process.kill(:TERM, @pid)
 			Process.wait(@pid)
 			
@@ -123,12 +132,12 @@ describe Async::Container::Controller do
 			expect(input.gets).to be == "Exiting...\n"
 			exit_time = input.gets.to_f
 			
-			expect(exit_time - graceful_shutdown_time).to be >= 1.0
+			expect(exit_time - graceful_shutdown_time).to be >= 0.01
 		end
 	end
 	
-	with 'bad controller' do
-		let(:controller_path) {File.expand_path(".bad.rb", __dir__)}
+	with "bad controller" do
+		let(:controller_path) {Async::Container::Controllers.path_for("bad")}
 		
 		let(:pipe) {IO.pipe}
 		let(:input) {pipe.first}
@@ -143,7 +152,7 @@ describe Async::Container::Controller do
 			super
 		end
 		
-		def after
+		def after(error = nil)
 			Process.kill(:TERM, @pid)
 			Process.wait(@pid)
 			
@@ -159,8 +168,8 @@ describe Async::Container::Controller do
 		end
 	end
 	
-	with 'signals' do
-		let(:controller_path) {File.expand_path(".dots.rb", __dir__)}
+	with "signals" do
+		let(:controller_path) {Async::Container::Controllers.path_for("dots")}
 		
 		let(:pipe) {IO.pipe}
 		let(:input) {pipe.first}
@@ -175,7 +184,7 @@ describe Async::Container::Controller do
 			super
 		end
 		
-		def after
+		def after(error = nil)
 			Process.kill(:TERM, @pid)
 			Process.wait(@pid)
 			
@@ -183,27 +192,42 @@ describe Async::Container::Controller do
 		end
 		
 		it "restarts children when receiving SIGHUP" do
-			expect(input.read(1)).to be == '.'
+			expect(input.read(1)).to be == "."
 			
 			Process.kill(:HUP, pid)
 			
-			expect(input.read(2)).to be == 'I.'
+			expect(input.read(2)).to be == "I."
 		end
 		
 		it "exits gracefully when receiving SIGINT" do
-			expect(input.read(1)).to be == '.'
+			expect(input.read(1)).to be == "."
 			
 			Process.kill(:INT, pid)
 			
-			expect(input.read).to be == 'I'
+			expect(input.read).to be == "I"
 		end
 		
 		it "exits gracefully when receiving SIGTERM" do
-			expect(input.read(1)).to be == '.'
+			expect(input.read(1)).to be == "."
 			
 			Process.kill(:TERM, pid)
 			
-			expect(input.read).to be == 'T'
+			expect(input.read).to be == "T"
+		end
+	end
+	
+	with "working directory" do
+		let(:controller_path) {Async::Container::Controllers.path_for("working_directory")}
+		
+		it "can change working directory" do
+			pipe = IO.pipe
+			
+			pid = Process.spawn("bundle", "exec", controller_path, out: pipe.last)
+			pipe.last.close
+			
+			expect(pipe.first.gets(chomp: true)).to be == "/"
+		ensure
+			Process.kill(:INT, pid) if pid
 		end
 	end
 end
