@@ -1,20 +1,21 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2020-2022, by Samuel Williams.
+# Copyright, 2020-2025, by Samuel Williams.
 # Copyright, 2020, by Olle Jonsson.
 
 require "async/container/controller"
+require "async/container/controllers"
 
 describe Async::Container::Notify::Pipe do
-	let(:notify_script) {File.expand_path(".notify.rb", __dir__)}
+	let(:notify_script) {Async::Container::Controllers.path_for("notify")}
 	
 	it "receives notification of child status" do
 		container = Async::Container.new
 		
 		container.spawn(restart: false) do |instance|
 			instance.exec(
-				"bundle", "exec", "--keep-file-descriptors",
+				"bundle", "exec",
 				notify_script, ready: false
 			)
 		end
@@ -23,7 +24,7 @@ describe Async::Container::Notify::Pipe do
 		container.sleep
 		
 		_child, state = container.state.first
-		expect(state).to be == {status: "Initializing..."}
+		expect(state).to be == {status: "Initializing controller..."}
 		
 		container.wait
 		
